@@ -16,7 +16,7 @@ my $p = ggplot(
     data    => $mpg,
     mapping => aes( x => 'displ', y => 'hwy' )
 )->geom_point()
- ->scale_y_log10();
+ ->scale_x_continuous(breaks => [2, 4, 6], labels => [qw(two four six)]);
 
 if ( defined $save_as ) {
     $p->save($save_as);
