@@ -4,7 +4,7 @@ package Chart::GGPlot::Backend::Plotly::Geom::Bar;
 
 use Chart::GGPlot::Class;
 
-our $VERSION = '0.0002_02'; # TRIAL VERSION
+our $VERSION = '0.0004_01'; # TRIAL VERSION
 
 with qw(Chart::GGPlot::Backend::Plotly::Geom);
 
@@ -12,7 +12,9 @@ use Module::Load;
 
 use Chart::GGPlot::Backend::Plotly::Util qw(to_rgb pdl_to_plotly);
 
-classmethod to_trace ($df, $params, $plot) {
+classmethod split_on () { [qw(fill)] }
+
+classmethod to_traces ($df, $params, $plot) {
     load Chart::Plotly::Trace::Bar;
     load Chart::Plotly::Trace::Bar::Marker;
 
@@ -37,8 +39,9 @@ classmethod to_trace ($df, $params, $plot) {
         marker    => $marker,
         hovertext => pdl_to_plotly( $df->at('hovertext') ),
         hoverinfo => 'text',
+        hoveron   => $class->hover_on,
     );
-    return $class->_adjust_trace_for_flip($trace, $plot);
+    return [ $class->_adjust_trace_for_flip($trace, $plot) ];
 }
 
 around _hovertext_data_for_aes( $orig, $class : $df, $aes ) {
@@ -65,7 +68,7 @@ Chart::GGPlot::Backend::Plotly::Geom::Bar - Chart::GGPlot's Plotly support for G
 
 =head1 VERSION
 
-version 0.0002_02
+version 0.0004_01
 
 =head1 SEE ALSO
 
