@@ -4,11 +4,11 @@ package Chart::GGPlot::Backend::Plotly::Geom::Blank;
 
 use Chart::GGPlot::Class;
 
-our $VERSION = '0.0002_02'; # TRIAL VERSION
+our $VERSION = '0.0004_01'; # TRIAL VERSION
 
 with qw(Chart::GGPlot::Backend::Plotly::Geom);
 
-classmethod to_trace ($df, $params, @rest) { }
+classmethod to_traces ($df, @rest) { [] }
 
 __PACKAGE__->meta->make_immutable;
 
@@ -26,7 +26,7 @@ Chart::GGPlot::Backend::Plotly::Geom::Blank - Chart::GGPlot's Plotly support for
 
 =head1 VERSION
 
-version 0.0002_02
+version 0.0004_01
 
 =head1 SEE ALSO
 
