@@ -4,7 +4,7 @@ package Chart::GGPlot::Backend::Plotly::Geom::Point;
 
 use Chart::GGPlot::Class;
 
-our $VERSION = '0.0002_02'; # TRIAL VERSION
+our $VERSION = '0.0004_01'; # TRIAL VERSION
 
 extends qw(Chart::GGPlot::Backend::Plotly::Geom::Path);
 
@@ -17,14 +17,14 @@ sub mode {
     return 'markers';
 }
 
-classmethod marker ($df, $params, @rest) {
+classmethod scatter_marker ($df, $params, @rest) {
     my $color = to_rgb( $df->at('color') );
     my $fill =
       $df->exists('fill')
       ? ifelse( $df->at('fill')->isbad, $color, to_rgb( $df->at('fill') ) )
       : $color;
     my $size = cex_to_px( $df->at('size') );
-    $size = ifelse( $size > 2, $size, 2 );
+    $size->where($size < 2) .= 2;
     my $opacity = $df->at('alpha')->setbadtoval(1);
     my $stroke  = cex_to_px( $df->at('stroke') );
 
@@ -67,7 +67,7 @@ Chart::GGPlot::Backend::Plotly::Geom::Point - Chart::GGPlot's Plotly support for
 
 =head1 VERSION
 
-version 0.0002_02
+version 0.0004_01
 
 =head1 SEE ALSO
 
