@@ -5,7 +5,7 @@ package Chart::GGPlot::Geom;
 use Chart::GGPlot::Role qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0002_02'; # TRIAL VERSION
+our $VERSION = '0.0004_01'; # TRIAL VERSION
 
 use Data::Frame::Util qw(guess_and_convert_to_pdl);
 use Types::Standard qw(ArrayRef CodeRef);
@@ -13,8 +13,6 @@ use Types::Standard qw(ArrayRef CodeRef);
 use Chart::GGPlot::Aes;
 use Chart::GGPlot::Util qw(:all);
 
-has optional_aes => ( is => 'ro', isa => ArrayRef, default => sub { [] } );
-
 with qw(
   Chart::GGPlot::HasRequiredAes
   Chart::GGPlot::HasDefaultAes
@@ -23,6 +21,8 @@ with qw(
   Chart::GGPlot::HasCollectibleFunctions
 );
 
+classmethod optional_aes() { [] }
+
 method setup_data ($data, $params) { $data }
 
 # Renders a single legend key.
@@ -95,7 +95,7 @@ Chart::GGPlot::Geom - The geom role
 
 =head1 VERSION
 
-version 0.0002_02
+version 0.0004_01
 
 =head1 AUTHOR
 
