@@ -4,7 +4,7 @@ package Chart::GGPlot::Geom::Functions;
 
 use Chart::GGPlot::Setup;
 
-our $VERSION = '0.0002_02'; # TRIAL VERSION
+our $VERSION = '0.0004_01'; # TRIAL VERSION
 
 use Chart::GGPlot::Util qw(collect_functions_from_package);
 
@@ -16,6 +16,8 @@ our @sub_namespaces = qw(
   Blank
   Bar Boxplot
   Path Point Line
+  Polygon
+  Smooth
 );
 
 for my $name (@sub_namespaces) {
@@ -48,7 +50,7 @@ Chart::GGPlot::Geom::Functions - Function interface for Chart::GGPlot::Geom
 
 =head1 VERSION
 
-version 0.0002_02
+version 0.0004_01
 
 =head1 DESCRIPTION
 
@@ -68,10 +70,11 @@ L<Chart::GGPlot::Plot> methods, to add layers into the plot object.
              :$na_rm=false, :$show_legend='auto', :$inherit_aes=true,
              %rest)
 
-The "bar" geom makes the height bar proportional to the number of cases in each group (or if the C<weight> aesthetic is supplied, the sum of the
+The "bar" geom makes the height bar proportional to the number of cases
+in each group (or if the C<weight> aesthetic is supplied, the sum of the
 C<weights>). 
-It uses C<stat_count()> by default: it counts the number of cases at each x
-position. 
+It uses C<stat_count()> by default: it counts the number of cases at
+each x position. 
 
 Arguments:
 
@@ -140,9 +143,9 @@ See also L<Chart::GGPlot::Stat::Functions/stat_count>.
                    :$na_rm=false, :$show_legend='auto', :$inherit_aes=true,
                    %rest)
 
-Visualise the distribution of a single continuous variable by dividing the 
-x axis into bins and counting the number of observations in each bin.
-This "histogram" geom displays the counts with bars.
+Visualise the distribution of a single continuous variable by dividing
+the x axis into bins and counting the number of observations in each
+bin. This "histogram" geom displays the counts with bars.
 
 =over 4
 
@@ -225,9 +228,9 @@ See also L<Chart::GGPlot::Stat::Functions/stat_bin>.
                  :$show_legend='auto', :$inherit_aes=true,
                  %rest)
 
-The boxplot compactly displays the distribution of a continuous variable. It
-visualises five summary statistics (the median, two hinges and two whiskers),
-and all "outlying" points individually.
+The boxplot compactly displays the distribution of a continuous
+variable. It visualises five summary statistics (the median, two hinges
+and two whiskers), and all "outlying" points individually.
 
 Arguments:
 
@@ -287,18 +290,19 @@ $outlier_alpha
 Default aesthetics for outliers. Set to C<undef> to inherit from the
 aesthetics used for the box.
 
-Sometimes it can be useful to hide the outliers, for example when overlaying
-the raw data points on top of the boxplot. Hiding the outliers can be
-achieved by setting C<outlier_shape =E<gt> ''>.
-Importantly, this does not remove the outliers, it only hides them, so the
-range calculated for the y-axis will be the same with outliers shown and
-outliers hidden.
+Sometimes it can be useful to hide the outliers, for example when
+overlaying the raw data points on top of the boxplot. Hiding the
+outliers can be achieved by setting C<outlier_shape =E<gt> ''>.
+Importantly, this does not remove the outliers, it only hides them, so
+the range calculated for the y-axis will be the same with outliers
+shown and outliers hidden.
 
 =item * $notch
 
-If false (default) make a standard box plot. If true, make a notched box
-plot. Notches are used to compare groups; if the notches of two boxes do not
-overlap, this suggests that the medians are significantly different.
+If false (default) make a standard box plot. If true, make a notched
+box plot. Notches are used to compare groups; if the notches of two
+boxes do not overlap, this suggests that the medians are significantly
+different.
 
 =item * $notchwidth
 
@@ -315,8 +319,8 @@ See also L<Chart::GGPlot::Stat::Functions/stat_boxplot>.
               :$inherit_aes=true, 
               %rest)
 
-The "path" geom connects the observations in the order in which they appear
-in the data.
+The "path" geom connects the observations in the order in which they
+appear in the data.
 
 =over 4
 
@@ -378,10 +382,10 @@ They may also be parameters to the paired geom/stat.
                %rest)
 
 The "point" geom is used to create scatterplots.
-The scatterplot is most useful for displaying the relationship between two
-continuous variables.
-A bubblechart is a scatterplot with a third variable mapped to the size of
-points.
+The scatterplot is most useful for displaying the relationship between
+two continuous variables.
+A bubblechart is a scatterplot with a third variable mapped to the size
+of points.
 
 Arguments:
 
@@ -444,8 +448,8 @@ They may also be parameters to the paired geom/stat.
               :$inherit_aes=true, 
               %rest)
 
-The "line" geom connects the observations in the order of the variable on
-the x axis.
+The "line" geom connects the observations in the order of the variable
+on the x axis.
 
 Arguments:
 
@@ -501,6 +505,141 @@ They may also be parameters to the paired geom/stat.
 
 =back
 
+=head2 geom_polygon
+
+    geom_polygon(:$mapping=undef, :$data=undef,
+                 :$stat='identity', :$position='identity',
+                 :$na_rm=false, :$show_legend='auto',
+                 :$inherit_aes=true,
+                 %rest)
+
+Polygons are very similar to paths (as drawn by C<geom_path()>)
+except that the start and end points are connected and the inside is
+colored by the C<fill> aesthetic. The C<group> aesthetic determines
+which cases are connected together into a polygon. 
+
+=over 4
+
+=item * $mapping
+
+Set of aesthetic mappings created by C<aes()>. If specified and
+C<$inherit_aes> is true (the default), it is combined with the default
+mapping at the top level of the plot.
+You must supply mapping if there is no plot mapping.
+
+=item * $data
+
+The data to be displayed in this layer.
+If C<undef>, the default, the data is inherited from the plot data as
+specified in the call to C<ggplot()>.
+
+=item * $stat
+
+The statistical transformation to use on the data for this layer, as a
+string.
+
+=item * $position
+
+Position adjustment, either as a string, or the result of a call to a
+position adjustment function.
+
+=item * $na_rm
+
+If false, the default, missing values are removed with a warning.
+If true, missing values are silently removed.
+
+=item * $show_legend
+
+Should this layer be included in the legends?
+'auto', the default, includes if any aesthetics are mapped.
+false never includes, and false always includes.
+
+=item * $inherit_aes
+
+If false, overrides the default aesthetics, rather than combining with them.
+This is most useful for helper functions that define both data and
+aesthetics and shouldn't inherit behaviour from the default plot
+specification.
+
+=item * %rest
+
+Other arguments passed to C<Chart::GGPlot::Layer-E<gt>new()>.
+These are often aesthetics, used to set an aesthetic to a fixed value,
+like C<color =E<gt> "red", size =E<gt> 3>.
+They may also be parameters to the paired geom/stat.
+
+=back
+
+=head2 geom_smooth
+
+    geom_smooth(:$mapping=undef, :$data=undef, :$stat='count',
+             :$position='stack', :$width=undef,
+             :$na_rm=false, :$show_legend='auto', :$inherit_aes=true,
+             %rest)
+
+Aids the eye in seeing patterns in the presence of overplotting, by
+calculating a smoothed conditional mean.
+
+C<geom_smooth()> and C<stat_smooth()> are effectively aliases: they
+both use the same arguments. Use C<stat_smooth()> if you want to
+display the results with a non-standard geom.
+
+Arguments:
+
+=over 4
+
+=item * $mapping
+
+Set of aesthetic mappings created by C<aes()>. If specified and
+C<$inherit_aes> is true (the default), it is combined with the default
+mapping at the top level of the plot.
+You must supply mapping if there is no plot mapping.
+
+=item * $data
+
+The data to be displayed in this layer.
+If C<undef>, the default, the data is inherited from the plot data as
+specified in the call to C<ggplot()>.
+
+=item * $stat
+
+The statistical transformation to use on the data for this layer, as a
+string.
+
+=item * $position
+
+Position adjustment, either as a string, or the result of a call to a
+position adjustment function.
+
+=item * $na_rm
+
+If false, the default, missing values are removed with a warning.
+If true, missing values are silently removed.
+
+=item * $show_legend
+
+Should this layer be included in the legends?
+'auto', the default, includes if any aesthetics are mapped.
+false never includes, and false always includes.
+
+=item * $inherit_aes
+
+If false, overrides the default aesthetics, rather than combining with them.
+This is most useful for helper functions that define both data and
+aesthetics and shouldn't inherit behaviour from the default plot
+specification.
+
+=item * %rest
+
+Other arguments passed to C<Chart::GGPlot::Layer-E<gt>new()>.
+These are often aesthetics, used to set an aesthetic to a fixed value,
+like C<color =E<gt> "red", size =E<gt> 3>.
+They may also be parameters to the paired geom/stat.
+
+=back
+
+See also L<Chart::GGPlot::Stat::Functions/stat_smooth>.
+
 =head1 SEE ALSO
 
 L<Chart::GGPlot::Layer>,
