@@ -5,9 +5,9 @@ package Chart::GGPlot::Guides;
 use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0002_02'; # TRIAL VERSION
+our $VERSION = '0.0004_01'; # TRIAL VERSION
 
-use Data::Munge qw(elem);
+use List::AllUtils;
 use Module::Load;
 
 has _guides => (is => 'ro', default => sub { {} });
@@ -24,6 +24,7 @@ my $defined_or = sub {
 
 # Train each scale in scales and generate the definition of guide.
 method build ($scales, :$labels, %rest) {
+    my @gdefs;
     for my $scale ($scales->scales->flatten) {
         for my $output ( $scale->aesthetics->flatten ) {
             my $guide = $self->get_guide($output) // $scale->guide;
@@ -37,18 +38,25 @@ method build ($scales, :$labels, %rest) {
             # Check the consistency of the guide and scale.
             my $guide_available_aes = $guide->available_aes;
             if ( defined $guide_available_aes
-                and !elem( $scale->aesthetics, $guide_available_aes ) )
+                and $guide_available_aes->intersect( $scale->aesthetics )
+                ->length == 0 )
             {
                 die sprintf( "Guide %s cannot be used for %s.",
-                    $guide, $scale->aesthetics );
+                    $guide, join( ', ', @{ $scale->aesthetics } ) );
             }
 
             unless (defined $guide->title) {
                 $guide->set('title', $scale->make_title( $scale->name // $labels->at($output) ));
             }
-            $self->set($output, $guide);
+
+            $guide = $guide->train($scale, $output);
+
+            if (defined $guide) { 
+                push @gdefs, $guide;
+            }
         }
     }
+    return \@gdefs;
 }
 
 method set($key, $guide) { $self->_guides->{$key} = $guide; }
@@ -83,7 +91,7 @@ Chart::GGPlot::Guides - The container of guides
 
 =head1 VERSION
 
-version 0.0002_02
+version 0.0004_01
 
 =head1 METHODS
 
