@@ -5,7 +5,7 @@ package Chart::GGPlot::Plot;
 use Chart::GGPlot::Class;
 use namespace::autoclean;
 
-our $VERSION = '0.0002_02'; # TRIAL VERSION
+our $VERSION = '0.0004_01'; # TRIAL VERSION
 
 use Autoload::AUTOCAN;
 use Data::Frame::Types qw(DataFrame);
@@ -161,6 +161,10 @@ method save ($filename, HashRef $opts={}) {
     $self->backend->save( $self, $filename, $opts );
 }
 
+method iplot (HashRef $opts={}) {
+    $self->backend->iplot( $self, $opts );
+}
+
 
 method summary () {
     my $s     = '';
@@ -273,7 +277,7 @@ Chart::GGPlot::Plot - ggplot class
 
 =head1 VERSION
 
-version 0.0002_02
+version 0.0004_01
 
 =head1 DESCRIPTION
 
@@ -314,6 +318,13 @@ Implementation depends on the plotting backend.
 Export the plot to a static image file.
 Implementation depends on the plotting backend.
 
+=head2 iplot
+
+    iplot(HashRef $opts={})
+
+Generate plot for L<IPerl> in Jupyter notebook.
+Implementation depends on the plotting backend.
+
 =head2 summary
 
     summary()
@@ -350,7 +361,7 @@ You normally don't have to explicitly call this method.
 
 =head2 add_coord
 
-    add_coord($scale)
+    add_coord($coord)
 
 You normally don't have to explicitly call this method.
 
@@ -413,6 +424,8 @@ C<add_layer()> is called.
 
 L<Chart::GGPlot>
 
+L<Devel::IPerl>
+
 =head1 AUTHOR
 
 Stephan Loyd <sloyd@cpan.org>
