@@ -7,7 +7,7 @@ package Chart::GGPlot::Util::Scales;
 
 use Chart::GGPlot::Setup qw(:base :pdl);
 
-our $VERSION = '0.0002_02'; # TRIAL VERSION
+our $VERSION = '0.0004_01'; # TRIAL VERSION
 
 use Color::Brewer;
 use Convert::Color::LCh;
@@ -261,8 +261,11 @@ fun _color_ramp ($colors) {
       } multi_array_gradient( 10, @hot_spots );
 
     return fun( Piddle $p) {
-        my @mapped =
-          map { $gradient[$_] } ( $p * ( @gradient - 1 ) )->rint->flatten;
+        my @mapped = do {
+            no warnings 'numeric';
+            map { $gradient[$_] } ( $p * ( @gradient - 1 ) )->rint->flatten;
+        };
+        
         my $rslt = PDL::SV->new( \@mapped );
         $rslt = $rslt->setbadif( $p->isbad ) if $p->badflag;
         return $rslt;
@@ -965,7 +968,7 @@ Chart::GGPlot::Util::Scales - R 'scales' package functions used by Chart::GGPlot
 
 =head1 VERSION
 
-version 0.0002_02
+version 0.0004_01
 
 =head1 FUNCTIONS
 
